@@ -79,7 +79,7 @@
 #' functions that expect symbolic arguments. The objects may also leak
 #' in representations of the call stack, such as [traceback()].
 #'
-#' @seealso call_modify
+#' @seealso [call_modify()]
 #' @examples
 #' # fn can either be a string, a symbol or a call
 #' call2("f", a = 1)
@@ -118,7 +118,8 @@ call2 <- function(.fn, ..., .ns = NULL) {
 #' # parameters without defaults:
 #' new_function(pairlist2(x = , y = 3 * 6), quote(x * y))
 pairlist2 <- function(...) {
-  .Call(ffi_dots_pairlist,
+  .Call(
+    ffi_dots_pairlist,
     frame_env = environment(),
     named = FALSE,
     ignore_empty = "trailing",
@@ -324,20 +325,17 @@ call_print_fine_type <- function(call) {
     `?unary` = ,
     `!` = ,
     `!!` = ,
-    `!!!` =
-      "prefix",
+    `!!!` = "prefix",
     `function` = ,
     `while` = ,
     `for` = ,
     `repeat` = ,
-    `if` =
-      "control",
+    `if` = "control",
     `(` = ,
-    `{` =
-      "delim",
+    `{{` = ,
+    `{` = "delim",
     `[` = ,
-    `[[` =
-      "subset",
+    `[[` = "subset",
     # These operators always print in infix form even if they have
     # more arguments
     `<-` = ,
@@ -346,8 +344,7 @@ call_print_fine_type <- function(call) {
     `::` = ,
     `:::` = ,
     `$` = ,
-    `@` =
-      "infix",
+    `@` = "infix",
     `+` = ,
     `-` = ,
     `?` = ,
@@ -368,12 +365,11 @@ call_print_fine_type <- function(call) {
     `%%` = ,
     `special` = ,
     `:` = ,
-    `^` =
-      if (length(node_cdr(call)) == 2) {
-        "infix"
-      } else {
-        "call"
-      }
+    `^` = if (length(node_cdr(call)) == 2) {
+      "infix"
+    } else {
+      "call"
+    }
   )
 }
 
@@ -523,7 +519,7 @@ call_has_precedence <- function(call, parent_call, side = NULL) {
 #' call_modify(call, na.rm = )
 #'
 #' # Supply a list of new arguments with `!!!`
-#' newargs <- list(na.rm = NULL, trim = 0.1)
+#' newargs <- list(na.rm = zap(), trim = 0.1)
 #' call <- call_modify(call, !!!newargs)
 #' call
 #'
@@ -557,18 +553,20 @@ call_has_precedence <- function(call, parent_call, side = NULL) {
 #' # subtle implications, for instance you can move an argument to
 #' # last position by removing it and remapping it:
 #' call <- quote(foo(bar = , baz))
-#' call_modify(call, bar = NULL, bar = missing_arg())
+#' call_modify(call, bar = zap(), bar = missing_arg())
 #'
 #' # You can also choose to keep only the first or last homonym
 #' # arguments:
-#' args <-  list(bar = NULL, bar = missing_arg())
+#' args <-  list(bar = zap(), bar = missing_arg())
 #' call_modify(call, !!!args, .homonyms = "first")
 #' call_modify(call, !!!args, .homonyms = "last")
-call_modify <- function(.call,
-                        ...,
-                        .homonyms = c("keep", "first", "last", "error"),
-                        .standardise = NULL,
-                        .env = caller_env()) {
+call_modify <- function(
+  .call,
+  ...,
+  .homonyms = c("keep", "first", "last", "error"),
+  .standardise = NULL,
+  .env = caller_env()
+) {
   args <- dots_list(..., .preserve_empty = TRUE, .homonyms = .homonyms)
 
   expr <- get_expr(.call)
@@ -715,12 +713,14 @@ abort_simple_call_input_type <- function(arg, fn, call = caller_env()) {
 #' call_match(quote(fn()), fn)
 #' call_match(quote(fn()), fn, defaults = TRUE)
 #' @export
-call_match <- function(call = NULL,
-                       fn = NULL,
-                       ...,
-                       defaults = FALSE,
-                       dots_env = NULL,
-                       dots_expand = TRUE) {
+call_match <- function(
+  call = NULL,
+  fn = NULL,
+  ...,
+  defaults = FALSE,
+  dots_env = NULL,
+  dots_expand = TRUE
+) {
   check_dots_empty0(...)
 
   if (is_null(call)) {
@@ -728,7 +728,7 @@ call_match <- function(call = NULL,
     fn <- fn %||% sys.function(sys.parent())
     dots_env <- dots_env %||% caller_env(2)
   } else {
-    dots_env <- dots_env %||% empty_env()
+    dots_env <- dots_env %||% env(empty_env(), ... = NULL)
   }
 
   if (is_null(fn)) {
@@ -840,7 +840,8 @@ call_name <- function(call) {
     return(NULL)
   }
 
-  switch(call_type(call),
+  switch(
+    call_type(call),
     named = as_string(node_car(call)),
     namespaced = as_string(node_cadr(node_cdar(call))),
     NULL
@@ -900,6 +901,48 @@ is_call_simple <- function(x, ns = NULL) {
   namespaced || is_symbol(head)
 }
 
+is_call_index <- function(x, ns = NULL) {
+  check_required(x)
+
+  if (!is_call(x)) {
+    return(FALSE)
+  }
+
+  out <- FALSE
+
+  while (is_call(fn <- x[[1]])) {
+    if (!is_call(fn, c("$", "@", "[", "[["))) {
+      return(FALSE)
+    }
+
+    if (!every(fn[-1], is_arg_index, ns)) {
+      return(FALSE)
+    }
+
+    out <- TRUE
+    x <- fn
+  }
+
+  out
+}
+
+is_arg_index <- function(arg, ns) {
+  if (!is_call(arg)) {
+    return(TRUE)
+  }
+
+  namespaced <- is_call(arg, c("::", ":::"))
+  if (namespaced) {
+    if (!is_null(ns) && !identical(namespaced, ns)) {
+      return(FALSE)
+    } else {
+      return(TRUE)
+    }
+  }
+
+  is_call_simple(arg)
+}
+
 #' Extract arguments from a call
 #'
 #' @inheritParams call_name
@@ -945,12 +988,18 @@ call_args_names <- function(call) {
 }
 
 is_qualified_call <- function(x) {
-  if (typeof(x) != "language") return(FALSE)
+  if (typeof(x) != "language") {
+    return(FALSE)
+  }
   is_qualified_symbol(node_car(x))
 }
 is_namespaced_call <- function(x, ns = NULL, private = NULL) {
-  if (typeof(x) != "language") return(FALSE)
-  if (!is_namespaced_symbol(node_car(x), ns, private)) return(FALSE)
+  if (typeof(x) != "language") {
+    return(FALSE)
+  }
+  if (!is_namespaced_symbol(node_car(x), ns, private)) {
+    return(FALSE)
+  }
   TRUE
 }
 
@@ -966,10 +1015,14 @@ call_unnamespace <- function(x) {
 
 # Qualified and namespaced symbols are actually calls
 is_qualified_symbol <- function(x) {
-  if (typeof(x) != "language") return(FALSE)
+  if (typeof(x) != "language") {
+    return(FALSE)
+  }
 
   head <- node_cadr(node_cdr(x))
-  if (typeof(head) != "symbol") return(FALSE)
+  if (typeof(head) != "symbol") {
+    return(FALSE)
+  }
 
   qualifier <- node_car(x)
   identical(qualifier, namespace_sym) ||
@@ -978,8 +1031,12 @@ is_qualified_symbol <- function(x) {
     identical(qualifier, at_sym)
 }
 is_namespaced_symbol <- function(x, ns = NULL, private = NULL) {
-  if (typeof(x) != "language") return(FALSE)
-  if (!is_null(ns) && !identical(node_cadr(x), sym(ns))) return(FALSE)
+  if (typeof(x) != "language") {
+    return(FALSE)
+  }
+  if (!is_null(ns) && !identical(node_cadr(x), sym(ns))) {
+    return(FALSE)
+  }
 
   head <- node_car(x)
   if (is_null(private)) {
