@@ -9,8 +9,8 @@
 #' * The predicates for vectors include the `n` argument for
 #'   pattern-matching on the vector length.
 #'
-#' * Unlike `is.atomic()`, `is_atomic()` does not return `TRUE` for
-#'   `NULL`.
+#' * Unlike `is.atomic()` in R < 4.4.0, `is_atomic()` does not return `TRUE` for
+#'   `NULL`. Starting in R 4.4.0 `is.atomic(NULL)` returns FALSE.
 #'
 #' * Unlike `is.vector()`, `is_vector()` tests if an object is an
 #'   atomic vector or a list. `is.vector` checks for the presence of
@@ -32,7 +32,13 @@ is_list <- function(x, n = NULL) {
   .Call(ffi_is_list, x, n)
 }
 
-parsable_atomic_types <- c("logical", "integer", "double", "complex", "character")
+parsable_atomic_types <- c(
+  "logical",
+  "integer",
+  "double",
+  "complex",
+  "character"
+)
 atomic_types <- c(parsable_atomic_types, "raw")
 #' @export
 #' @rdname type-predicates
@@ -70,11 +76,7 @@ is_complex <- function(x, n = NULL, finite = NULL) {
 is_character <- function(x, n = NULL) {
   .Call(ffi_is_character, x, n, NULL, NULL)
 }
-is_character2 <- function(x,
-                          n = NULL,
-                          ...,
-                          missing = TRUE,
-                          empty = TRUE) {
+is_character2 <- function(x, n = NULL, ..., missing = TRUE, empty = TRUE) {
   check_dots_empty0(...)
 
   # FIXME: Change API at C-level so that `TRUE` means no restriction
@@ -188,10 +190,6 @@ is_bool <- function(x) {
   is_logical(x, n = 1) && !is.na(x)
 }
 
-is_number <- function(x) {
-  is_integerish(x, n = 1, finite = TRUE)
-}
-
 #' Bare type predicates
 #'
 #' These predicates check for a given type but only return `TRUE` for
@@ -201,8 +199,9 @@ is_number <- function(x) {
 #' * The predicates for vectors include the `n` argument for
 #'   pattern-matching on the vector length.
 #'
-#' * Like [is_atomic()] and unlike base R `is.atomic()`,
-#'   `is_bare_atomic()` does not return `TRUE` for `NULL`.
+#' * Like [is_atomic()] and unlike base R `is.atomic()` for R < 4.4.0,
+#'   `is_bare_atomic()` does not return `TRUE` for `NULL`. Starting in
+#'   R 4.4.0, `is.atomic(NULL)` returns FALSE.
 #'
 #' * Unlike base R `is.numeric()`, `is_bare_double()` only returns
 #'   `TRUE` for floating point numbers.
@@ -244,7 +243,9 @@ is_bare_integer <- function(x, n = NULL) {
 #' @export
 #' @rdname bare-type-predicates
 is_bare_numeric <- function(x, n = NULL) {
-  if (!is_null(n) && length(x) != n) return(FALSE)
+  if (!is_null(n) && length(x) != n) {
+    return(FALSE)
+  }
   !is.object(x) && typeof(x) %in% c("double", "integer")
 }
 #' @export
@@ -404,19 +405,16 @@ type_of_ <- function(x) {
 #' # These objects that can only be changed with side effect are not
 #' # copyable:
 #' is_copyable(env)
-#'
-#' structure(base::list, foo = "bar")
-#' str(base::list)
 is_copyable <- function(x) {
-  switch(typeof(x),
+  switch(
+    typeof(x),
     NULL = ,
     char = ,
     symbol = ,
     special = ,
     builtin = ,
     environment = ,
-    externalptr =
-      FALSE,
+    externalptr = FALSE,
     TRUE
   )
 }
@@ -497,7 +495,8 @@ rlang_type_sum.data.frame <- function(x) class(x)[[1]]
 #' @export
 rlang_type_sum.default <- function(x) {
   if (!is.object(x)) {
-    switch(typeof(x),
+    switch(
+      typeof(x),
       logical = "lgl",
       integer = "int",
       double = "dbl",
@@ -507,12 +506,11 @@ rlang_type_sum.default <- function(x) {
       special = ,
       closure = "fn",
       environment = "env",
-      symbol =
-        if (is_missing(x)) {
-          "missing"
-        } else {
-          "sym"
-        },
+      symbol = if (is_missing(x)) {
+        "missing"
+      } else {
+        "sym"
+      },
       typeof(x)
     )
   } else if (!isS4(x)) {
