@@ -41,7 +41,7 @@ const char* rlang_format_error_arg(r_obj* arg) {
 
   // Uses the vmax protection stack.
   char* out = R_alloc(n, sizeof(char));
-  memcpy(out, arg_str, n);
+  r_memcpy(out, arg_str, n);
 
   FREE(1);
   return out;
@@ -141,7 +141,7 @@ void without_winch(void* payload) {
   r_poke_option("rlang_trace_use_winch", data->old_use_winch);
 }
 
-r_obj* ffi_test_stop_internal() {
+r_obj* ffi_test_stop_internal(void) {
   r_stop_internal("foo");
   return r_null;
 }
@@ -150,19 +150,18 @@ r_obj* ffi_test_stop_internal() {
 // Probably should be implemented at R level
 r_obj* ffi_new_condition(r_obj* class,
                          r_obj* msg,
-                         r_obj* data,
-                         r_obj* error_call) {
+                         r_obj* data) {
   if (msg == r_null) {
     msg = r_chrs.empty_string;
   } else if (r_typeof(msg) != R_TYPE_character) {
     const char* arg = r_format_error_arg(r_sym("message"));
-    const char* what = obj_type_friendly(msg);
+    const char* what = r_obj_type_friendly(msg);
     r_abort("%s must be a character vector, not %s.", arg, what);
   }
 
   if (r_typeof(class) != R_TYPE_character) {
     const char* arg = r_format_error_arg(r_sym("class"));
-    const char* what = obj_type_friendly(class);
+    const char* what = r_obj_type_friendly(class);
     r_abort("%s must be a character vector, not %s.", arg, what);
   }
 
@@ -202,8 +201,12 @@ r_obj* new_condition_names(r_obj* data) {
   return nms;
 }
 
-const char* obj_type_friendly(r_obj* x) {
-  r_obj* out_obj = KEEP(r_eval_with_x(friendly_type_of_call, x, rlang_ns_env));
+// `length` is no longer a valid argument
+const char* rlang_obj_type_friendly_full(r_obj* x, bool value, bool _length) {
+  r_obj* out_obj = KEEP(r_eval_with_xy(obj_type_friendly_call,
+                                       x,
+                                       r_lgl(value),
+                                       rlang_ns_env));
 
   if (!r_is_string(out_obj)) {
     r_stop_unexpected_type(r_typeof(out_obj));
@@ -213,23 +216,22 @@ const char* obj_type_friendly(r_obj* x) {
   // Uses the vmax protection stack.
   int n = strlen(out_str) + 1;
   char* out = R_alloc(n, sizeof(char));
-  memcpy(out, out_str, n);
+  r_memcpy(out, out_str, n);
 
   FREE(1);
   return out;
 }
 
-
 void rlang_init_cnd(r_obj* ns) {
   format_arg_call = r_parse("format_arg(x)");
   r_preserve(format_arg_call);
 
-  friendly_type_of_call = r_parse("obj_type_friendly(x)");
-  r_preserve(friendly_type_of_call);
+  obj_type_friendly_call = r_parse("obj_type_friendly(x, y)");
+  r_preserve(obj_type_friendly_call);
 }
 
 static
 r_obj* format_arg_call = NULL;
 
 static
-r_obj* friendly_type_of_call = NULL;
+r_obj* obj_type_friendly_call = NULL;
