@@ -1,5 +1,8 @@
 #include <rlang.h>
+#include "env.h"
 #include "internal.h"
+#include "quo.h"
+#include "utils.h"
 
 
 static r_obj* quo_mask_flag_sym = NULL;
@@ -51,7 +54,7 @@ static r_obj* rlang_new_data_pronoun(r_obj* mask) {
   return pronoun;
 }
 static r_obj* rlang_new_ctxt_pronoun(r_obj* top) {
-  r_obj* pronoun = KEEP(r_alloc_environment(0, r_env_parent(top)));
+  r_obj* pronoun = KEEP(r_alloc_empty_environment(r_env_parent(top)));
 
   r_attrib_poke(pronoun, r_syms.class_, ctxt_pronoun_class);
 
@@ -141,14 +144,15 @@ static r_obj* mask_sym = NULL;
 
 static r_obj* tilde_fn = NULL;
 static r_obj* restore_mask_fn = NULL;
+static r_obj* restore_mask_formals = NULL;
+static r_obj* restore_mask_body = NULL;
 
 static void on_exit_restore_lexical_env(r_obj* mask, r_obj* old, r_obj* frame) {
-  r_obj* fn = KEEP(r_clone(restore_mask_fn));
-
   r_obj* env = KEEP(r_alloc_environment(2, r_envs.base));
   r_env_poke(env, mask_sym, mask);
   r_env_poke(env, old_sym, old);
-  r_fn_poke_env(fn, env);
+
+  r_obj* fn = KEEP(r_new_function(restore_mask_formals, restore_mask_body, env));
 
   r_obj* call = KEEP(r_new_call(fn, r_null));
   r_on_exit(call, frame);
@@ -160,14 +164,14 @@ r_obj* ffi_new_data_mask(r_obj* bottom, r_obj* top) {
   r_obj* data_mask;
 
   if (bottom == r_null) {
-    bottom = KEEP(r_alloc_environment(100, r_envs.empty));
+    bottom = KEEP(r_alloc_environment(10, r_envs.empty));
     data_mask = bottom;
   } else {
     check_data_mask_input(bottom, "bottom");
     // Create a child because we don't know what might be in `bottom`
     // and we need to clear its contents without deleting any object
     // created in the data mask environment
-    data_mask = KEEP(r_alloc_environment(100, bottom));
+    data_mask = KEEP(r_alloc_environment(10, bottom));
   }
 
   if (top == r_null) {
@@ -244,8 +248,8 @@ r_obj* ffi_data_pronoun_get(r_obj* pronoun, r_obj* sym, r_obj* error_call) {
   r_obj* obj = mask_find(pronoun, sym);
 
   if (obj == r_syms.unbound) {
-    r_obj* call = KEEP(r_parse("rlang:::abort_data_pronoun(x, call = y)"));
-    r_eval_with_xy(call, sym, error_call, r_envs.base);
+    r_obj* call = KEEP(r_parse("abort_data_pronoun(x, call = y)"));
+    r_eval_with_xy(call, sym, error_call, rlang_ns_env);
     r_abort("Internal error: .data subsetting should have failed earlier");
   }
 
@@ -253,7 +257,7 @@ r_obj* ffi_data_pronoun_get(r_obj* pronoun, r_obj* sym, r_obj* error_call) {
   return obj;
 }
 
-static void warn_env_as_mask_once() {
+static void warn_env_as_mask_once(void) {
   const char* msg =
     "Passing an environment as data mask is deprecated.\n"
     "Please use `new_data_mask()` to transform your environment to a mask.\n"
@@ -267,7 +271,7 @@ static void warn_env_as_mask_once() {
     "  # Good:\n"
     "  mask <- new_data_mask(env)\n"
     "  eval_tidy(expr, mask)";
-  warn_deprecated(msg, msg);
+  deprecate_warn(msg, msg);
 }
 
 static r_obj* data_pronoun_sym = NULL;
@@ -549,7 +553,7 @@ r_obj* ffi_eval_tidy(r_obj* call, r_obj* op, r_obj* args, r_obj* rho) {
 }
 
 
-void rlang_init_eval_tidy() {
+void rlang_init_eval_tidy(void) {
   r_obj* rlang_ns_env = KEEP(r_ns_env("rlang"));
 
   tilde_fn = r_eval(r_sym("tilde_eval"), rlang_ns_env);
@@ -597,5 +601,11 @@ void rlang_init_eval_tidy() {
   );
   r_preserve(restore_mask_fn);
 
+  restore_mask_formals = r_fn_formals(restore_mask_fn);
+  r_preserve(restore_mask_formals);
+
+  restore_mask_body = r_fn_body(restore_mask_fn);
+  r_preserve(restore_mask_body);
+
   FREE(1);
 }
