@@ -1,8 +1,9 @@
 #include <rlang.h>
 #include <ctype.h>
-#include "internal.h"
+#include <stdlib.h>
 
 #include "decl/names-decl.h"
+#include "utils.h"
 
 // 3 leading '.' + 1 trailing '\0' + 24 characters
 #define MAX_IOTA_SIZE 28
@@ -64,7 +65,7 @@ r_obj* names_as_unique(r_obj* names, bool quiet) {
     char buf[buf_size];
     buf[0] = '\0';
 
-    memcpy(buf, name, size);
+    r_memcpy(buf, name, size);
     int remaining = buf_size - size;
 
     int needed = snprintf(buf + size,
