@@ -1,3 +1,6 @@
+# https://github.com/r-lib/rlang/issues/1556
+skip_if_not(has_size_one_bool())
+
 r_string <- function(str) {
   stopifnot(is_string(str))
   .Call(ffi_r_string, str)
@@ -14,12 +17,13 @@ test_that("chr_append() appends", {
 })
 
 test_that("r_warn() signals", {
-  handler <- function(c) expect_null(c$call)
-
-  expect_warning(regexp = "foo",
-    with_handlers(warning = calling(handler),
+  expect_warning(
+    regexp = "foo",
+    withCallingHandlers(
+      warning = function(c) expect_null(c$call),
       .Call(ffi_test_r_warn, "foo")
-    ))
+    )
+  )
 })
 
 test_that("r_on_exit() adds deferred expr", {
@@ -77,11 +81,32 @@ test_that("r_which_operator() returns correct tokens", {
   expect_identical(call_parse_type(""), "")
 
   expect_identical(call_parse_type(quote(?a)), "?unary")
-  expect_identical(call_parse_type(quote(a ? b)), "?")
+  expect_identical(call_parse_type(quote(a?b)), "?")
 
-  expect_identical(call_parse_type(quote(while (a) b)), "while")
-  expect_identical(call_parse_type(quote(for (a in b) b)), "for")
-  expect_identical(call_parse_type(quote(repeat a)), "repeat")
+  expect_identical(
+    call_parse_type(quote(
+      while (a) {
+        b
+      }
+    )),
+    "while"
+  )
+  expect_identical(
+    call_parse_type(quote(
+      for (a in b) {
+        b
+      }
+    )),
+    "for"
+  )
+  expect_identical(
+    call_parse_type(quote(
+      repeat {
+        a
+      }
+    )),
+    "repeat"
+  )
   expect_identical(call_parse_type(quote(if (a) b)), "if")
   expect_identical(call_parse_type(quote(break)), "break")
   expect_identical(call_parse_type(quote(next)), "next")
@@ -146,7 +171,7 @@ test_that("r_which_operator() returns correct tokens", {
 
   expect_identical(call_parse_type(quote(a * b)), "*")
   expect_identical(call_parse_type(quote(a / b)), "/")
-  expect_identical(call_parse_type(quote(a ^ b)), "^")
+  expect_identical(call_parse_type(quote(a^b)), "^")
   expect_identical(call_parse_type(quote(a$b)), "$")
   expect_identical(call_parse_type(quote(a@b)), "@")
   expect_identical(call_parse_type(quote(a[b])), "[")
@@ -164,7 +189,12 @@ test_that("r_which_operator() returns correct tokens", {
   expect_identical(call_parse_type(quote(`%%-`(a))), "")
 
   expect_identical(call_parse_type(quote((a))), "(")
-  expect_identical(call_parse_type(quote({ a })), "{")
+  expect_identical(
+    call_parse_type(quote({
+      a
+    })),
+    "{"
+  )
   expect_identical(call_parse_type(quote(`(-`(a))), "")
   expect_identical(call_parse_type(quote(`{-`(a))), "")
 })
@@ -174,7 +204,7 @@ test_that("client library passes tests", {
   return("Disabled")
 
   # Avoid installing into system library by default
-  skip_if(!nzchar(Sys.getenv("RLANG_FULL_TESTS")))
+  skip_if_not(nzchar(Sys.getenv("RLANG_FULL_TESTS")))
 
   skip_on_cran()
   skip_on_ci()
@@ -212,12 +242,12 @@ test_that("client library passes tests", {
   file.copy(src_path, temp_test_dir, overwrite = TRUE, recursive = TRUE)
   pkg_path <- file.path(temp_test_dir, "rlanglibtest")
 
-
   # We store the library as a zip to avoid VCS noise. Use
   # fixtures/Makefile to regenerate it.
   utils::unzip(zip_file, exdir = file.path(pkg_path, "src"))
 
-  install.packages(pkg_path,
+  install.packages(
+    pkg_path,
     repos = NULL,
     type = "source",
     lib = temp_lib,
@@ -226,7 +256,11 @@ test_that("client library passes tests", {
     quiet = TRUE
   )
 
-  result <- tools::testInstalledPackage("rlanglibtest", lib.loc = temp_lib, types = "test")
+  result <- tools::testInstalledPackage(
+    "rlanglibtest",
+    lib.loc = temp_lib,
+    types = "test"
+  )
   expect_identical(result, 0L)
 })
 
@@ -325,7 +359,6 @@ test_that("r_attrib_set() zaps several elements", {
   expect_true(is_reference(attrs1, node_cdr(attrs)))
   expect_true(is_reference(node_cdr(attrs1), node_cddr(attrs)))
 
-
   out2 <- c_set_attribute(x, "bar", NULL)
   attrs2 <- get_attributes(out2)
 
@@ -333,7 +366,6 @@ test_that("r_attrib_set() zaps several elements", {
   expect_false(is_reference(attrs2, attrs))
   expect_true(is_reference(node_cdr(attrs2), node_cddr(attrs)))
 
-
   out3 <- c_set_attribute(x, "baz", NULL)
   attrs3 <- get_attributes(out3)
 
@@ -356,7 +388,13 @@ test_that("can zap non-existing attributes", {
 })
 
 test_that("r_parse()", {
-  expect_equal(.Call(ffi_test_parse, "{ foo; bar }"), quote({ foo; bar }))
+  expect_equal(
+    .Call(ffi_test_parse, "{ foo; bar }"),
+    quote({
+      foo
+      bar
+    })
+  )
   expect_error(.Call(ffi_test_parse, "foo; bar"), "single expression")
   expect_error(.Call(ffi_test_parse, "foo\n bar"), "single expression")
 })
@@ -370,8 +408,9 @@ test_that("r_parse_eval()", {
 test_that("failed parses are printed if `rlang__verbose_errors` is non-NULL", {
   expect_error(
     expect_output(
-      regexp =  "foo; bar",
-      with_options(rlang__verbose_errors = TRUE,
+      regexp = "foo; bar",
+      with_options(
+        rlang__verbose_errors = TRUE,
         .Call(ffi_test_parse, "foo; bar")
       )
     ),
@@ -379,10 +418,10 @@ test_that("failed parses are printed if `rlang__verbose_errors` is non-NULL", {
   )
 })
 
-test_that("r_warn_deprecated() warns once", {
-  expect_warning(warn_deprecated("retired", "foo"), "retired")
-  expect_no_warning(warn_deprecated("retired", "foo"))
-  expect_warning(warn_deprecated("retired", "bar"), "retired")
+test_that("r_deprecate_warn() warns once", {
+  expect_warning(deprecate_warn("retired", "foo"), "retired")
+  expect_no_warning(deprecate_warn("retired", "foo"))
+  expect_warning(deprecate_warn("retired", "bar"), "retired")
 })
 
 test_that("nms_are_duplicated() detects duplicates", {
@@ -400,6 +439,7 @@ test_that("nms_are_duplicated() handles empty and missing names", {
 
 test_that("r_lgl_sum() handles NA", {
   expect_identical(r_lgl_sum(lgl(TRUE, FALSE), TRUE), 1L)
+  expect_identical(r_lgl_sum(lgl(TRUE, FALSE), FALSE), 1L)
   expect_identical(r_lgl_sum(lgl(TRUE, NA), TRUE), 2L)
   expect_identical(r_lgl_sum(lgl(TRUE, NA), FALSE), 1L)
 })
@@ -407,19 +447,41 @@ test_that("r_lgl_sum() handles NA", {
 test_that("r_lgl_which() handles NA", {
   expect_identical(r_lgl_which(lgl(TRUE, FALSE), TRUE), 1L)
   expect_identical(r_lgl_which(lgl(TRUE, FALSE), FALSE), 1L)
-  expect_identical(r_lgl_which(lgl(TRUE, NA), TRUE), int(1L, NA))
-  expect_identical(r_lgl_which(lgl(TRUE, NA), FALSE), 1L)
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), TRUE),
+    int(1L, NA, NA, 5L, NA)
+  )
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, NA), FALSE),
+    int(1L, 5L)
+  )
 })
 
 test_that("r_lgl_which() handles empty vectors", {
   expect_identical(r_lgl_which(lgl(), TRUE), int())
   expect_identical(r_lgl_which(lgl(), FALSE), int())
+
+  expect_identical(r_lgl_which(named(lgl()), TRUE), named(int()))
+  expect_identical(r_lgl_which(named(lgl()), FALSE), named(int()))
+})
+
+test_that("r_lgl_which() propagates names", {
+  x <- lgl(a = TRUE, b = FALSE, c = NA, d = FALSE, e = NA, f = TRUE)
+  expect_named(r_lgl_which(x, na_propagate = TRUE), c("a", "c", "e", "f"))
+  expect_named(r_lgl_which(x, na_propagate = FALSE), c("a", "f"))
+
+  # Unnamed if input is unnamed
+  expect_named(r_lgl_which(TRUE, na_propagate = TRUE), NULL)
+  expect_named(r_lgl_which(lgl(TRUE, NA), na_propagate = TRUE), NULL)
 })
 
 test_that("r_lgl_which() handles `NA` when propagation is disabled (#750)", {
   expect_identical(r_lgl_which(lgl(TRUE, FALSE, NA), FALSE), int(1))
   expect_identical(r_lgl_which(lgl(TRUE, FALSE, NA, TRUE), FALSE), int(1, 4))
-  expect_identical(r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, FALSE, TRUE), FALSE), int(1, 5, 7))
+  expect_identical(
+    r_lgl_which(lgl(TRUE, NA, FALSE, NA, TRUE, FALSE, TRUE), FALSE),
+    int(1, 5, 7)
+  )
 })
 
 test_that("r_pairlist_rev() reverses destructively", {
@@ -556,10 +618,9 @@ test_that("can put again after del", {
   expect_true(dict_put(dict, quote(foo), 2))
   expect_equal(dict_get(dict, quote(foo)), 2)
 
-
   # Used to fail because we deleted whole bucket instead of just a
   # node when this node appeared first in the bucket
-  
+
   dict <- new_dict(3L)
   dict_put(dict, chr_get("1"), NULL)
   dict_put(dict, chr_get("foo"), NULL)
@@ -718,9 +779,11 @@ test_that("can preserve and unpreserve repeatedly", {
   expect_false(dict_has(dict(), x))
 
   rlang_preserve(x)
-  on.exit(while (dict_has(dict(), x)) {
-    rlang_unpreserve(x)
-  })
+  on.exit(
+    while (dict_has(dict(), x)) {
+      rlang_unpreserve(x)
+    }
+  )
 
   expect_true(dict_has(dict(), x))
 
@@ -747,7 +810,10 @@ test_that("alloc_data_frame() creates data frame", {
   expect_equal(ncol(df), 3)
   expect_equal(class(df), "data.frame")
   expect_equal(names(df), c("a", "b", "c"))
-  expect_equal(lapply(df, typeof), list(a = "integer", b = "double", c = "character"))
+  expect_equal(
+    lapply(df, typeof),
+    list(a = "integer", b = "double", c = "character")
+  )
   expect_equal(lapply(df, length), list(a = 2, b = 2, c = 2))
 
   df <- alloc_data_frame(0L, chr(), int())
@@ -794,12 +860,44 @@ test_that("can shrink vectors", {
   expect_equal(out, as.list(1:2))
 
   # Uses truelength to modify in place on recent R
-  if (getRversion() >= "3.4.0") {
+  if (getRversion() >= "3.4.0" && getRversion() < "4.6.0") {
     expect_equal(x_atomic, 1:2)
     expect_equal(x_list, as.list(1:2))
   }
 })
 
+test_that("can grow vectors allocated with vec_alloc()", {
+  x <- vec_alloc("integer", 3L)
+  x[1:3] <- 1:3
+  out <- vec_resize(x, 5)
+  expect_length(out, 5)
+  expect_equal(x, 1:3)
+  expect_equal(out[1:3], x)
+
+  x <- vec_alloc("list", 3L)
+  x[[1]] <- 1
+  x[[2]] <- 2
+  x[[3]] <- 3
+  out <- vec_resize(x, 5)
+  expect_length(out, 5)
+  expect_equal(x[[1]], 1)
+  expect_equal(out[1:3], x[1:3])
+})
+
+test_that("can shrink vectors allocated with vec_alloc()", {
+  x_atomic <- vec_alloc("integer", 3L)
+  x_atomic[1:3] <- 1:3
+  out <- vec_resize(x_atomic, 2)
+  expect_equal(out, 1:2)
+
+  x_list <- vec_alloc("list", 3L)
+  x_list[[1]] <- 1
+  x_list[[2]] <- 2
+  x_list[[3]] <- 3
+  out <- vec_resize(x_list, 2)
+  expect_equal(out, list(1, 2))
+})
+
 test_that("can grow and shrink dynamic arrays", {
   arr <- new_dyn_array(1, 3)
 
@@ -988,15 +1086,18 @@ test_that("can shrink and grow dynamic barrier vectors", {
   expect_equal(dyn_count(arr), 2)
 })
 
-test_that("can get and poke elements", {
+test_that("can get, push, and poke elements", {
   arr <- new_dyn_vector("logical", 3)
   dyn_push_back(arr, TRUE)
+  dyn_lgl_push_back(arr, TRUE)
+  expect_equal(dyn_lgl_get(arr, 0L), TRUE)
+  expect_equal(dyn_lgl_get(arr, 1L), TRUE)
   dyn_lgl_poke(arr, 0L, FALSE)
   expect_equal(dyn_lgl_get(arr, 0L), FALSE)
 
   arr <- new_dyn_vector("integer", 3)
   dyn_push_back(arr, 1L)
-  dyn_push_back(arr, 2L)
+  dyn_int_push_back(arr, 2L)
   expect_equal(dyn_int_get(arr, 0L), 1L)
   expect_equal(dyn_int_get(arr, 1L), 2L)
   dyn_int_poke(arr, 0L, 10L)
@@ -1004,27 +1105,44 @@ test_that("can get and poke elements", {
 
   arr <- new_dyn_vector("double", 3)
   dyn_push_back(arr, 1.5)
-  dyn_dbl_poke(arr, 0L, 2.5)
-  expect_equal(dyn_dbl_get(arr, 0L), 2.5)
+  dyn_dbl_push_back(arr, 2.5)
+  expect_equal(dyn_dbl_get(arr, 0L), 1.5)
+  expect_equal(dyn_dbl_get(arr, 1L), 2.5)
+  dyn_dbl_poke(arr, 0L, 3.5)
+  expect_equal(dyn_dbl_get(arr, 0L), 3.5)
 
   arr <- new_dyn_vector("complex", 3)
   dyn_push_back(arr, 0i)
-  dyn_cpl_poke(arr, 0L, 1i)
-  expect_equal(dyn_cpl_get(arr, 0L), 1i)
+  dyn_cpl_push_back(arr, 1i)
+  expect_equal(dyn_cpl_get(arr, 0L), 0i)
+  expect_equal(dyn_cpl_get(arr, 1L), 1i)
+  dyn_cpl_poke(arr, 0L, 2i)
+  expect_equal(dyn_cpl_get(arr, 0L), 2i)
 
   arr <- new_dyn_vector("raw", 3)
   dyn_push_back(arr, as.raw(1))
-  dyn_raw_poke(arr, 0L, as.raw(2))
-  expect_equal(dyn_raw_get(arr, 0L), as.raw(2))
+  dyn_raw_push_back(arr, as.raw(2))
+  expect_equal(dyn_raw_get(arr, 0L), as.raw(1))
+  expect_equal(dyn_raw_get(arr, 1L), as.raw(2))
+  dyn_raw_poke(arr, 0L, as.raw(3))
+  expect_equal(dyn_raw_get(arr, 0L), as.raw(3))
 
   arr <- new_dyn_vector("character", 3)
-  dyn_push_back(arr, chr_get("foo", 0L))
-  val <- chr_get("bar", 0L)
-  dyn_chr_poke(arr, 0L, val)
-  expect_true(identical(dyn_chr_get(arr, 0L), val))
+  foo <- chr_get("foo", 0L)
+  bar <- chr_get("bar", 0L)
+  dyn_push_back(arr, foo)
+  dyn_chr_push_back(arr, bar)
+  expect_true(identical(dyn_chr_get(arr, 0L), foo))
+  expect_true(identical(dyn_chr_get(arr, 1L), bar))
+  baz <- chr_get("bar", 0L)
+  dyn_chr_poke(arr, 0L, baz)
+  expect_true(identical(dyn_chr_get(arr, 0L), baz))
 
   arr <- new_dyn_vector("list", 3)
   dyn_push_back(arr, 1:2)
+  dyn_list_push_back(arr, 3:4)
+  expect_equal(dyn_list_get(arr, 0L), 1:2)
+  expect_equal(dyn_list_get(arr, 1L), 3:4)
   dyn_list_poke(arr, 0L, 11:12)
   expect_equal(dyn_list_get(arr, 0L), 11:12)
 })
@@ -1074,7 +1192,7 @@ test_that("can push to dynamic list-of", {
 })
 
 test_that("internal error is thrown with OOB dyn-lof access", {
-  skip_if(!compiled_by_gcc())
+  skip_if_not(compiled_by_gcc())
   lof <- new_dyn_list_of("integer", 3, 2)
   expect_snapshot({
     err(lof_arr_push_back(lof, 0, 42L), "Location 0 does not exist")
@@ -1129,6 +1247,8 @@ test_that("can push to arrays in dynamic list-of", {
 })
 
 test_that("sexp iterator visits in full order", {
+  skip_if_not(has_private_accessors())
+
   it_dirs <- function(snapshot) {
     dirs <- sapply(snapshot, `[[`, "dir")
     dirs <- table(dirs)
@@ -1176,9 +1296,9 @@ test_that("re-encoding fails purposefully with any bytes", {
   bytes <- rawToChar(as.raw(0xdc))
   Encoding(bytes) <- "bytes"
 
-  expect_snapshot(
-    (expect_error(r_obj_encode_utf8(bytes)))
-  )
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
+    r_obj_encode_utf8(bytes)
+  })
 
   for (enc in test_encodings()) {
     expect_snapshot(
@@ -1297,12 +1417,15 @@ local({
 
 test_that("r_stop_internal() mentions expected namespace", {
   fn <- function() {
-    .Call(get("ffi_test_stop_internal", envir = asNamespace("rlang")), "Message.")
+    .Call(
+      get("ffi_test_stop_internal", envir = asNamespace("rlang")),
+      "Message."
+    )
   }
 
   environment(fn) <- ns_env("base")
-  expect_error(fn(), "in the base package")
+  expect_error(fn(), "detected in the base package")
 
   environment(fn) <- ns_env("utils")
-  expect_error(fn(), "in the utils package")
+  expect_error(fn(), "detected in the utils package")
 })
