@@ -16,7 +16,9 @@ test_that("tree printing only changes deliberately", {
   e <- environment()
 
   i <- function(i) j(i)
-  j <- function(i) { k(i) }
+  j <- function(i) {
+    k(i)
+  }
   k <- function(i) {
     NULL
     l(i)
@@ -46,16 +48,21 @@ test_that("can print tree with collapsed branches", {
   dir <- normalizePath(test_path(".."))
   e <- environment()
 
-  f <- function() { g() }
-  g <- function() { tryCatch(h(), foo = identity, bar = identity) }
-  h <- function() { tryCatch(i(), baz = identity) }
-  i <- function() { tryCatch(trace_back(e, bottom = 0)) }
+  f <- function() {
+    g()
+  }
+  g <- function() {
+    tryCatch(h(), foo = identity, bar = identity)
+  }
+  h <- function() {
+    tryCatch(i(), baz = identity)
+  }
+  i <- function() {
+    tryCatch(trace_back(e, bottom = 0))
+  }
   trace <- eval(quote(f()))
 
-  expect_snapshot_trace(trace,
-    dir = dir,
-    srcrefs = TRUE
-  )
+  expect_snapshot_trace(trace, dir = dir, srcrefs = TRUE)
 
   # With multiple siblings
   f <- function() eval(quote(eval(quote(g()))))
@@ -63,10 +70,7 @@ test_that("can print tree with collapsed branches", {
   h <- function() trace_back(e)
   trace <- eval(quote(f()))
 
-  expect_snapshot_trace(trace,
-    dir = dir,
-    srcrefs = TRUE
-  )
+  expect_snapshot_trace(trace, dir = dir, srcrefs = TRUE)
 })
 
 test_that("trace_simplify_branch() extracts last branch", {
@@ -122,7 +126,8 @@ test_that("trace picks up option `rlang_trace_top_env` for trimming trace", {
   e <- current_env()
   f1 <- function() trace_back()
   f2 <- function() trace_back(e)
-  with_options(rlang_trace_top_env = current_env(),
+  with_options(
+    rlang_trace_top_env = current_env(),
     expect_identical(trace_length(f1()), trace_length(f2()))
   )
 })
@@ -172,7 +177,10 @@ test_that("long backtrace branches are truncated", {
     print(trace, simplify = "branch", max_frames = 1, srcrefs = FALSE)
   })
 
-  expect_error(print(trace, simplify = "none", max_frames = 5), "currently only supported with")
+  expect_error(
+    print(trace, simplify = "none", max_frames = 5),
+    "currently only supported with"
+  )
 })
 
 test_that("eval() frames are collapsed", {
@@ -243,7 +251,7 @@ test_that("combinations of incomplete and leading pipes collapse properly", {
   trace <- F(NA) %>% T()
   expect_snapshot_trace(trace)
 
-  trace <- F(NA) %>% F() %>%  T()
+  trace <- F(NA) %>% F() %>% T()
   expect_snapshot_trace(trace)
 })
 
@@ -304,6 +312,8 @@ test_that("anonymous calls are stripped from backtraces", {
 })
 
 test_that("collapsing of eval() frames detects when error occurs within eval()", {
+  skip_if_not_installed("base", "4.5")
+
   e <- NULL
   trace <- NULL
 
@@ -315,9 +325,9 @@ test_that("collapsing of eval() frames detects when error occurs within eval()",
     eval()
   }
 
-  catch_cnd(with_handlers(
+  catch_cnd(withCallingHandlers(
     fn(),
-    error = calling(function(err) trace <<- trace_back(e))
+    error = function(err) trace <<- trace_back(e)
   ))
 
   expect_snapshot_trace(trace)
@@ -378,7 +388,10 @@ test_that("unexported functions have `:::` prefix", {
 
   # Should be installed as part of the C API tests
   skip_if_not_installed("rlanglibtest")
-  test_trace_unexported_child <- env_get(ns_env("rlanglibtest"), "test_trace_unexported_child")
+  test_trace_unexported_child <- env_get(
+    ns_env("rlanglibtest"),
+    "test_trace_unexported_child"
+  )
 
   e <- current_env()
   f <- function() test_trace_unexported_child(e)
@@ -434,7 +447,9 @@ test_that("can trim layers of backtraces", {
   e <- current_env()
   f <- function(n) identity(identity(g(n)))
   g <- function(n) identity(identity(h(n)))
-  h <- function(n) identity(identity(trace_back(e, bottom = caller_env(n - 1L))))
+  h <- function(n) {
+    identity(identity(trace_back(e, bottom = caller_env(n - 1L))))
+  }
 
   trace1_env <- f(1)
   trace2_env <- f(2)
@@ -452,7 +467,7 @@ test_that("fails when `bottom` is not on the stack", {
 test_that("caught error does not display backtrace in knitted files", {
   skip_if_not_installed("knitr")
   skip_if_not_installed("rmarkdown")
-  skip_if(!rmarkdown::pandoc_available())
+  skip_if_not(rmarkdown::pandoc_available())
 
   local_options(
     rlang_backtrace_on_error = NULL,
@@ -463,7 +478,7 @@ test_that("caught error does not display backtrace in knitted files", {
   lines <- render_md("test-trace.Rmd")
   error_line <- lines[[length(lines)]]
   expect_match(error_line, "foo$")
-  
+
   expect_snapshot({
     cat_line(render_md("test-trace-full.Rmd"))
   })
@@ -512,7 +527,7 @@ test_that("can slice backtrace", {
   )
 
   exp <- new_trace(alist(a(), c()), c(0L, 0L))
-  
+
   expect_identical(
     trace_slice(trace, c(1, 3)),
     exp
@@ -532,7 +547,7 @@ test_that("can bind backtraces", {
 
   expect_equal(trace_bind(), new_trace(list(), int()))
   expect_equal(trace_bind(trace1), trace1)
-  
+
   trace2 <- new_trace(alist(foo(), bar(), baz()), c(0L, 1L, 1L))
   out <- trace_bind(trace1, trace2)
 
@@ -548,9 +563,6 @@ test_that("can bind backtraces", {
 })
 
 test_that("backtraces don't contain inlined objects (#1069, r-lib/testthat#1223)", {
-  # !! deparsing in older R
-  skip_if_not_installed("base", "3.5.0")
-
   local_options(
     rlang_trace_format_srcrefs = FALSE
   )
@@ -632,10 +644,13 @@ test_that("can format empty traces", {
 
 test_that("backtrace is formatted with sources (#1396)", {
   file <- tempfile("my_source", fileext = ".R")
-  with_srcref(file = file, "
+  with_srcref(
+    file = file,
+    "
     f <- function() g()
     g <- function() abort('foo')
-  ")
+  "
+  )
   err <- catch_cnd(f(), "error")
 
   rlang_cli_local_hyperlinks()
@@ -732,3 +747,61 @@ test_that("namespaced calls are highlighted", {
     print_highlighted_trace(err)
   })
 })
+
+test_that("can highlight long lists of arguments in backtrace (#1456)", {
+  f <- function(...) {
+    g(
+      aaaaaaaaaaaa = aaaaaaaaaaaa,
+      bbbbbbbbbbbb = bbbbbbbbbbbb,
+      cccccccccccc = cccccccccccc,
+      dddddddddddd = dddddddddddd,
+      eeeeeeeeeeee = eeeeeeeeeeee,
+      ...
+    )
+  }
+  g <- function(
+    aaaaaaaaaaaa,
+    bbbbbbbbbbbb,
+    cccccccccccc,
+    dddddddddddd,
+    eeeeeeeeeeee,
+    ...
+  ) {
+    rlang::abort("foo", ...)
+  }
+
+  err <- catch_error(f())
+  expect_snapshot({
+    print_highlighted_trace(err)
+  })
+
+  err <- catch_error(f(arg = "bbbbbbbbbbbb"))
+  expect_snapshot({
+    print_highlighted_trace(err)
+  })
+})
+
+test_that("can highlight multi-line arguments in backtrace (#1456)", {
+  f <- function(...) {
+    g(
+      x = {
+        a
+        b
+      },
+      ...
+    )
+  }
+  g <- function(x, ...) {
+    rlang::abort("foo", ...)
+  }
+
+  err <- catch_error(f())
+  expect_snapshot({
+    print_highlighted_trace(err)
+  })
+
+  err <- catch_error(f(arg = "x"))
+  expect_snapshot({
+    print_highlighted_trace(err)
+  })
+})
